/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.giro.gambit.apps;

import java.util.HashMap;
import java.util.Map;

import edu.uml.lgdc.database.ConnectItem;
import edu.uml.lgdc.database.ConnectList;
import edu.uml.lgdc.project.settings.OptSecDescriptor;
import edu.uml.lgdc.project.settings.OptionDesc;
import edu.uml.lgdc.project.settings.OptionsIO;

public class GambitDbConnectSettings extends OptSecDescriptor {
	static public final String SEC_NAME = "GAMBIT Database Connect";

	/** GAMBIT user connection string */
	static private final String PAR_GAMBIT_USER = "GAMBIT_user";
	
	private ConnectItem gambitUserConnectItem;
	
	private final Map<String, OptionDesc> descriptor;

	public GambitDbConnectSettings() {
		descriptor = new HashMap<>();
		setDefaults();
	}
	public void setDefaults() {
		gambitUserConnectItem = ConnectItem.createEmpty();
		fillDefaults();
	}
	@Override public GambitDbConnectSettings getThis() {
		return this;
	}
	@Override public String getName() {
		return SEC_NAME;
	}
	@Override public Map<String, OptionDesc> getOptionsDescriptor() {
		return descriptor;
	}
	@Override public String[] optionRenameHook(String unknowmParamName, String valueOfUnknownParamName) {
		return null;
	}
	private void fillDefaults() {
		descriptor.put(PAR_GAMBIT_USER, new OptionDesc(gambitUserConnectItem, false));
	}
	@Override public void getFrom(OptionsIO paramsIO) {
		String strVal = paramsIO.get(SEC_NAME, PAR_GAMBIT_USER);
		gambitUserConnectItem = (strVal != null ?  ConnectItem.parse(strVal) : ConnectItem.createEmpty());
	}
	@Override public void putTo(OptionsIO paramsIO) {
		paramsIO.put(SEC_NAME, PAR_GAMBIT_USER, gambitUserConnectItem.toString());
	}
	public ConnectItem getGambitUserConnectItem() {
		return gambitUserConnectItem;
	}
	public void setGambitUserConnectItem(ConnectItem gambitUserConnectItem) {
		this.gambitUserConnectItem = gambitUserConnectItem;
	}
	/**
	 * The connector list contains only one GAMBIT database in this design
	 * @return
	 */
	public ConnectList getGambitConnectList() {
		return new ConnectList(new ConnectItem[] {getGambitUserConnectItem()}, 0);		
	}
}
