/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.giro.gambit.apps;

import java.io.File;
import java.io.InputStream;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import edu.uml.lgdc.project.settings.OptSecDescriptor;
import edu.uml.lgdc.project.settings.OptionsIO;
import edu.uml.lgdc.project.settings.OptionsIOini;

public class GambitReaderSettings {
	protected OptionsIO paramsIO;
	protected GambitDbConnectSettings gambitDbConnectSettings;  
	
	protected  final File file;

	transient private Map<String, OptSecDescriptor> thisDescriptors;
	transient private Set<String> duplicates;
	
	public GambitReaderSettings(String iniFileName) {
		this(iniFileName, false);
	}
	
	public GambitReaderSettings(String iniFileName, boolean noIniFileAbsentMsg) {
		createGroups();
		paramsIO = new OptionsIOini(getAllDescriptors(), iniFileName, true, noIniFileAbsentMsg);
		file = ((OptionsIOini)paramsIO).getFile();
	}
	
	public GambitReaderSettings(InputStream inputStream) {
		createGroups();
		paramsIO = new OptionsIOini(getAllDescriptors(), inputStream);
		file = null;
	}
	
	public File getFile() {
		return file;
	}

	protected void createGroups() {
		thisDescriptors = new HashMap<>();
		duplicates = new HashSet<>();
		gambitDbConnectSettings = createGambitDbConnectSettings(); 
		if (duplicates.size() > 0) {
			throw new RuntimeException("Design error: duplicated settings groups, " + Arrays.toString(duplicates.toArray()));
		}
		duplicates = null; // don't need it anymore
	}
	
	protected Map<String, OptSecDescriptor<?>> getAllDescriptors() {
		Map<String, OptSecDescriptor<?>> allDescriptors = new HashMap<>();
		allDescriptors.put(gambitDbConnectSettings.getName(), gambitDbConnectSettings);
		return allDescriptors;
	}
	protected GambitDbConnectSettings createGambitDbConnectSettings() {
		return (GambitDbConnectSettings)checkDescriptors(new GambitDbConnectSettings()); 
	}
	private OptSecDescriptor checkDescriptors(OptSecDescriptor descriptor) {
		if (thisDescriptors.put(descriptor.getName(), descriptor) != null) {
			duplicates.add(descriptor.getName());
		}
		return descriptor;
	}
	
	public OptionsIO getParamsIO() {
		return paramsIO;
	}

	public GambitDbConnectSettings getGambitDbConnectSettings() {
		return gambitDbConnectSettings;
	}

}
