package edu.uml.giro.gambit.core;

import java.util.Objects;

import edu.uml.giro.gambit.synthesizers.GeoSynthesizer;
import edu.uml.lgdc.geospace.CharChoice;
import edu.uml.lgdc.geospace.Geomap;

/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/

public class Characteristic {
	public final CharChoice cc;
	
	// 2D map data structures
	public final GeoSynthesizer climate;
	public final Geomap climateMap; // at the target time
	public GeoSynthesizer weather;
	public Geomap weatherMap; // at the target time
	public Geomap deviationMap; // at the target time
	public final Geomap deviationMap_percent; // at the target time

	// arrays of data at sensor sites
	public final LocalData localData;
	
	public Characteristic(CharChoice cc, Geomap climateMap, GeoSynthesizer climate, LocalData localData, Geomap weatherMap,
			GeoSynthesizer weather, Geomap deviationMap, Geomap deviationMap_percent) {
		this.cc = Objects.requireNonNull(cc);
		this.climateMap = Objects.requireNonNull(climateMap);
		this.climate = Objects.requireNonNull(climate);
		this.localData = Objects.requireNonNull(localData);
		this.weather = weather;
		this.weatherMap = Objects.requireNonNull(weatherMap);
		this.deviationMap = Objects.requireNonNull(deviationMap);
		this.deviationMap_percent = Objects.requireNonNull(deviationMap_percent);
	}

	public void reset() {
		// no need to reset climate as it is always there
		if( localData != null ) localData.reset();
		if( weatherMap != null) weatherMap.reset();
		if( deviationMap != null) deviationMap.reset();
		if( deviationMap_percent != null ) deviationMap_percent.reset();
	}
	
	public void setNewWeatherSynthesizer( GeoSynthesizer weather ) {
		this.weather = Objects.requireNonNull(weather);
		weather.reset();
	}

}