/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.giro.gambit.core;

import edu.uml.lgdc.quantities.NO_VALUE;

public class IonogramScaling {

	// confidence levels
	public static final int FORECAST_CONFIDENCE_SCORE = 31;
	public static final int POOR_CONFIDENCE_SCORE = 41;
	public static final int UNKNOWN_CONFIDENCE_SCORE = 51;
	public static final int GOOD_CONFIDENCE_SCORE = 80;
	public static final int MANUAL_CONFIDENCE_SCORE = 999;
	public static final int NOT_APPLICABLE_CONFIDENCE_SCORE = -1;
	
	// flags
	public static final int ACCEPTED_ASIS = 0x1;
	public static final int INTERPOLATED_MISSING = 0x2;
	public static final int INTERPOLATED_POOR_QUALITY = 0x4;
	public static final int INTERPOLATED = INTERPOLATED_MISSING + INTERPOLATED_POOR_QUALITY;
	public static final int DAY_BOUNDARY = 0x8;
	public static final int FORECAST = 0x10;
	
	// thresholds
	public static final int TIMEGRID_MISMATCH_THRESHOLD = 33;

	

	public static boolean isMissing( double rawObservation ) {
		return rawObservation == NO_VALUE.SPECIAL;
	}
	
	public static boolean isPoorQuality( int confidenceScore ) {
		return confidenceScore < POOR_CONFIDENCE_SCORE;
	}
	
	public static boolean isHighQuality( int confidenceScore ) {
		return confidenceScore > GOOD_CONFIDENCE_SCORE;
	}
	
	public static boolean isManual( int confidenceScore ) {
		return confidenceScore == MANUAL_CONFIDENCE_SCORE;
	}

	public static boolean isUnknownQuality( int confidenceScore ) {
		return confidenceScore == UNKNOWN_CONFIDENCE_SCORE;
	}

	public static boolean isTooFar( int timeGridMismatchPercent ) {
		return timeGridMismatchPercent > TIMEGRID_MISMATCH_THRESHOLD;
	}
	
	public static boolean isAcceptedAsIs( int gambitFlag ) {
		return (gambitFlag&ACCEPTED_ASIS) > 0;
	}
	
	public static boolean isDayBoundary( int gambitFlag ) {
		return (gambitFlag&DAY_BOUNDARY) > 0;
	}
	
	public static boolean isFilledGap( int gambitFlag ) {
		return (gambitFlag&INTERPOLATED_MISSING) > 0;
	}

	public static boolean isReplaced( int gambitFlag ) {
		return (gambitFlag&INTERPOLATED_POOR_QUALITY) > 0;
	}
	
	public static boolean isForecast( int gambitFlag ) {
		return (gambitFlag&FORECAST) > 0;
	}
}
