/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.giro.gambit.core;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import edu.uml.giro.gambit.database.StationLocation;
import edu.uml.lgdc.math.SimpleMetrics;
import edu.uml.lgdc.quantities.NO_VALUE;
import edu.uml.lgdc.time.TimeScale;

public class LocalDataAllSitesOneTime {

	public HashMap <StationLocation, LocalDataElements> data = new HashMap <StationLocation, LocalDataElements> ();
	// metrics accompany requested data via getValues
	private SimpleMetrics metrics = new SimpleMetrics();
	private TimeScale time;
	
	public LocalDataAllSitesOneTime( LocalData input, TimeScale targetTime ) {
		if( !targetTime.equals( time ) ) {
			data.clear();
			for (int iSite = 0; iSite < input.totalLocations; iSite++) {
				if( input.sites[iSite].isUnused())
					continue;
				LocalDataElements site = input.sites[iSite].data.getCell(targetTime);
				if( site.isEmpty() )
					continue;
				data.put( input.sites[iSite].getLocation(), site );
			}
		}
	}

	public SimpleMetrics getMetrics(SitesChoice sitesChoice, boolean percent) {

		List<Double> values = new ArrayList<Double>();
		
		for( LocalDataElements site : data.values() ) {
			double value = getValue( site, sitesChoice, percent); 
			if( value != NO_VALUE.SPECIAL )
				values.add( value );
		}
		if( values.size() == 0 ) {
			metrics.clear();
		}
		else {
			double[] array = new double[ values.size()];
			for( int i=0; i< values.size(); i++)
				array[i] = values.get(i);
			metrics.compute( array, values.size(), NO_VALUE.SPECIAL);
		}
		return metrics;
	}
	
	public HashMap <StationLocation, LocalDataElements> getData() {
		return data;
	}
	
	public double getValue( LocalDataElements site, SitesChoice sc, boolean percent ) {
		double value;
		if( sc.isObservations() )
			value = site.getObservation();
		else
			if( sc.isVersusEmpiricalModel() )
				value = percent? site.getO2C_percent() : site.getO2C();
			else
				if( sc.isVersusIrtam() )
					value = percent? site.getO2GW_percent() : site.getO2GW();
				else
					throw new RuntimeException("Unknown sites choice");
		return value;
	}
}
