package edu.uml.giro.gambit.core;

import edu.uml.lgdc.geospace.CharChoice;
/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
public enum SitesChoice {
	FOF2_OBSERVATIONS("foF2: GIRO data", "Observations at GIRO locations", CharChoice.FOF2.getDidbaseIdent()), 
	FOF2_DEVIATIONS_CLIMATE("foF2: observed minus climate", "Difference between measured and IRI-modeled foF2 at GIRO locations", CharChoice.FOF2.getDidbaseIdent()), 
	FOF2_DEVIATIONS_WEATHER("foF2: observed minus weather", "Difference between measured and IRTAM-modeled foF2 at GIRO locations", CharChoice.FOF2.getDidbaseIdent()), 
	NMF2_OBSERVATIONS("NmF2: GIRO data", "Observations at GIRO locations", CharChoice.NMF2.getDidbaseIdent()), 
	NMF2_DEVIATIONS_CLIMATE("NmF2: observed minus climate", "Difference between measured and IRI-modeled NmF2 at GIRO locations", CharChoice.NMF2.getDidbaseIdent()), 
	NMF2_DEVIATIONS_WEATHER("NmF2: observed minus weather", "Difference between measured and IRTAM-modeled NmF2 at GIRO locations", CharChoice.NMF2.getDidbaseIdent()), 
	HMF2_OBSERVATIONS("hmF2: GIRO data", "Observations at GIRO locations", CharChoice.HMF2.getDidbaseIdent()), 
	HMF2_DEVIATIONS_CLIMATE("hmF2: observed minus climate", "Difference between measured and Brunini-modeled hmF2 at GIRO locations", CharChoice.HMF2.getDidbaseIdent()), 
	HMF2_DEVIATIONS_WEATHER("hmF2: observed minus weather", "Difference between measured and IRTAM-modeled hmF2 at GIRO locations", CharChoice.HMF2.getDidbaseIdent()),
	B0_OBSERVATIONS("B0: GIRO data", "Observations at GIRO locations", CharChoice.B0.getDidbaseIdent()), 
	B0_DEVIATIONS_CLIMATE("B0: observed minus climate", "Difference between measured and IRI-modeled B0 at GIRO locations", CharChoice.B0.getDidbaseIdent()), 
	B0_DEVIATIONS_WEATHER("B0: observed minus weather", "Difference between measured and IRTAM-modeled B0 at GIRO locations", CharChoice.B0.getDidbaseIdent()),
	B1_OBSERVATIONS("B1: GIRO data", "Observations at GIRO locations", CharChoice.B1.getDidbaseIdent()), 
	B1_DEVIATIONS_CLIMATE("B1: observed minus climate", "Difference between measured and IRI-modeled B0 at GIRO locations", CharChoice.B1.getDidbaseIdent()), 
	B1_DEVIATIONS_WEATHER("B1: observed minus weather", "Difference between measured and IRTAM-modeled B0 at GIRO locations", CharChoice.B1.getDidbaseIdent());

	private final String shortName;
	private final String description;
	private int charIdent;

	static {
		boolean isMapTypeDefined[] = new boolean[SitesChoice.values().length];
		int iChoice = 0;
		for (SitesChoice choice : SitesChoice.values()) {
			isMapTypeDefined[iChoice] = false;
			isMapTypeDefined[iChoice] = isVersusIrtam(choice) || isVersusEmpericelModel(choice) || isObservations(choice);
			iChoice++;
		}
		iChoice = 0;
		for (SitesChoice choice : SitesChoice.values()) {
			if (!isMapTypeDefined[iChoice])
				throw new RuntimeException("Type is not defined for " + choice.toString() + ". In SiteChoice.");
			iChoice++;
		}
	}

	static {
		for (CharChoice cc : CharChoice.values()) {
			for (SitesTypeChoice stc : SitesTypeChoice.values()) {
				if (getSiteChoice(cc, stc) == null ) {
					throw new RuntimeException("Define SiteChoice for CharChoice " + cc.name() + " and SiteTypeChoice " + stc.name());
				}
			}
		}
	}

	private SitesChoice(String shortName, String description, int charIdent) {
		this.shortName = shortName;
		this.description = description;
		this.charIdent = charIdent;
	}

	static public SitesChoice getSiteChoice(CharChoice cc, SitesTypeChoice stc) {
		try {
			return SitesChoice.valueOf(cc.name() + "_" + stc.name());
		} catch (Exception e) {
			return null;
		}
	}

	public String shortName() {
		return shortName;
	}

	public String getDescription() {
		return description;
	}

	public CharChoice getCC() {
		return CharChoice.getByIdent(charIdent);
	}

	static private boolean isVersusIrtam(SitesChoice choice) {
		return choice == FOF2_DEVIATIONS_WEATHER || choice == NMF2_DEVIATIONS_WEATHER 
				|| choice == HMF2_DEVIATIONS_WEATHER || choice == B0_DEVIATIONS_WEATHER 
				|| choice == B1_DEVIATIONS_WEATHER; 
	}

	public boolean isVersusIrtam() {
		return isVersusIrtam(this);
	}

	static private boolean isVersusEmpericelModel(SitesChoice choice) {
		return choice == FOF2_DEVIATIONS_CLIMATE || choice == NMF2_DEVIATIONS_CLIMATE 
				|| choice == HMF2_DEVIATIONS_CLIMATE || choice == B0_DEVIATIONS_CLIMATE 
				|| choice == B1_DEVIATIONS_CLIMATE;
	}

	public boolean isVersusEmpiricalModel() {
		return isVersusEmpericelModel(this);
	}

	static private boolean isObservations(SitesChoice choice) {
		return choice == FOF2_OBSERVATIONS || choice == NMF2_OBSERVATIONS 
				|| choice == HMF2_OBSERVATIONS || choice == B0_OBSERVATIONS 
				|| choice == B1_OBSERVATIONS; 
	}

	public boolean isObservations() {
		return isObservations(this);
	}

	static public int length() {
		return values().length;
	}

	static public SitesChoice get(int ordinal) {
		if (check(ordinal))
			return values()[ordinal];
		else
			throw new IllegalArgumentException("Illegal SitesChoice ordinal, " + ordinal);
	}

	static public String[] shortNames(boolean initialCaps) {
		final SitesChoice[] values = values();
		String[] shortNames = new String[values.length];
		for (int i = 0; i < values.length; i++)
			shortNames[i] = values[i].shortName;
		return shortNames;
	}

	static public boolean check(int value) {
		return value >= 0 && value < values().length;
	}

}
