/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.giro.gambit.expansions;

import edu.uml.giro.gambit.core.GambitConstants;
import edu.uml.lgdc.geospace.EarthGrid;
import edu.uml.lgdc.geospace.TimeGrid;
import edu.uml.lgdc.time.TimeScale;

/**
 * Expansion basis API for empirical models
 * 
 */

abstract public class ExpansionBasis {

	// Expansion basis values are pre-computed for a grid
	protected EarthGrid earthGrid = null;
	protected TimeGrid timeGrid = null;

	protected String name;

	public void setExpansionBasisName(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	/**
	 * General method to store implementation specific functionality. Any time
	 * dependent parameters should be update inside this method.
	 * 
	 * @param ut
	 */
	public void setNewTime(TimeScale ut) {
		timeGrid.setUTs(ut, GambitConstants.FORECAST_DURATION_MIN);
	}

	public void setEarthGrid(EarthGrid earthGrid) {
		this.earthGrid = earthGrid;
	}

	public void setTimeGrid(TimeGrid timeGrid) {
		this.timeGrid = timeGrid;
	}

	public EarthGrid getEarthGrid() {
		return earthGrid;
	}

	public TimeGrid getTimeGrid() {
		return timeGrid;
	}

}
