/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.giro.gambit.synthesizers;

import edu.uml.giro.gambit.coefficients.Coefficients;
import edu.uml.giro.gambit.expansions.ExpansionBasis;
import edu.uml.lgdc.geospace.CharChoice;
import edu.uml.lgdc.geospace.EarthGrid;
import edu.uml.lgdc.geospace.TimeGrid;

abstract public class Synthesizer {
	public CharChoice cc;
	protected ExpansionBasis basis;
	protected Coefficients<?> coeffs;

	protected int irtamVersionIdent;
	protected String assimilationMethodName;

	public void setAssimilationMethodName(String name) {
		assimilationMethodName = name;
	}

	public void setIrtamVersionIdent(int id) {
		irtamVersionIdent = id;
	}
	
	public int getIrtamVersionIdent() {
		return irtamVersionIdent;
	}

	public String getAssimilationMethodName() {
		return assimilationMethodName;
	}

	public Synthesizer(CharChoice cc, ExpansionBasis basis, Coefficients<?> coeffs) {
		this.cc = cc;
		this.basis = basis;
		this.coeffs = coeffs;
	}

	public void setEarthGrid(EarthGrid earthGrid) {
		basis.setEarthGrid(earthGrid);
	}

	public void setTimeGrid(TimeGrid timeGrid) {
		basis.setTimeGrid(timeGrid);
	}

	public void setBasis( ExpansionBasis basis ) {
		this.basis = basis;
	}
	
	public ExpansionBasis getExpansionBasis() {
		return basis;
	}

	public Coefficients<?> getCoefficients() {
		return coeffs;
	}

	public EarthGrid getEarthGrid() {
		return basis.getEarthGrid();
	}

	public TimeGrid getTimeGrid() {
		return basis.getTimeGrid();
	}

	public void reset() {
		if (coeffs != null)
			coeffs.reset();
	}

	/**
	 * Synthesizes output value at given location and time Location is given as
	 * 2 indices to the earthGrid Time is given as index to the timeGrid
	 * 
	 * @param iLat
	 * @param iLon
	 * @param iTime
	 * @return
	 */

	abstract public double synthesizeValue(double lat, double lon, int iTime);
	abstract public double synthesizeTrend(double lat, double lon, int iTime);

	/**
	 * Calculates time series of values at given location Location is given as 2
	 * indices to the earthGrid
	 * 
	 * @param iLat
	 * @param iLon
	 * @return
	 */
	abstract public double[] synthesizeValueSeries(int iLat, int iLon);

	public double[] synthesizeValueSeries(double lat, double lon) {
		return synthesizeValueSeries(basis.getEarthGrid().getGridLatIndex(lat), basis.getEarthGrid().getGridLonIndex(lon));
	}

	abstract public double[][] synthesizeValueMap(int iTime);

}
