/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.appuserdb.api;

import java.util.HashMap;
import java.util.Map;

public enum UserRole {
	GUEST			(1, "Guest", 			false, false, false), 
	USER			(2, "User", 			true,  false, false), 
	USER_REALTIME	(3, "UserRealTime", 	true,  true,  false), 
	EXPERT			(4, "Expert", 			true,  false, true), 
	REAL_TIMER		(5, "RealTimer", 		false, true,  true); 

	static private final Map<Integer, UserRole> mapById = new HashMap<>();
	static private final Map<String, UserRole> mapByName = new HashMap<>();

	static {
		for (UserRole userRole : values()) {
			if (mapById.put(userRole.getId(), userRole) != null)
				throw new RuntimeException("design error: duplicated id " + userRole.getId());
			if (mapByName.put(userRole.getName().toLowerCase(), userRole) != null)
				throw new RuntimeException("design error: duplicated name " + userRole.getName());
		}
	}
	
	private final int id;
	private final String name;
	private final boolean authenticatedAccess;
	private final boolean realTimeAccess;
	private final boolean writeAccess;
	
	private UserRole(int id, String name, boolean authenticatedAccess, boolean realtimeAccess, boolean writeAccess) {
		this.id = id;
		this.name = name;
		this.authenticatedAccess = authenticatedAccess;
		this.realTimeAccess = realtimeAccess;
		this.writeAccess = writeAccess;
	}

	public String getName() {
		return name;
	}
	public boolean getAuthenticatedAccess() {
		return authenticatedAccess;
	}
	public boolean getRealTimeAccess() {
		return realTimeAccess;
	}
	public boolean getWriteAccess() {
		return writeAccess;
	}
	public int getId() {
		return id;
	}
	public boolean adequateAuthentication(boolean applicationNeed) {
		return !applicationNeed || authenticatedAccess;
	}
	public boolean adequateRealTimeAccess(boolean applicationNeed) {
		return !applicationNeed || realTimeAccess;
	}
	public boolean adequateWriteAccess(boolean applicationNeed) {
		return !applicationNeed || writeAccess;
	}
	public boolean matchingAccess(boolean authenticationNeed, boolean realTimeNeed, boolean writeNeed) {
		return adequateAuthentication(authenticationNeed) && adequateRealTimeAccess(realTimeNeed) && adequateWriteAccess(writeNeed);
	}
	static public UserRole get(int id) {
		return mapById.get(id);
	}
	static public UserRole get(String name) {
		return mapByName.get(name.toLowerCase());
	}
}
