/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.appuserdb.constants;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Alex Kozlov
 */
public enum Application {
	GAMBIT_COEFF_SERVLET	 	(1, "GambitCoefficients_servlet"),
	TIDX_BACKEND				(2, "TIDExplorer_Backend"),
	GAMBIT_EXPLORER_USERAPP		(3, "GambitExplorer_UserApp"),
	GAMBIT_EXPLORER_MASTERAPP	(4, "GambitExplorer_MasterApp"),
	RAYTRIX_OI_IONOGRAM_SERVLET	(5, "Raytrix_ObliqIonoSynth_Servlet"),
	RAYTRIX_AOA_FF_SERVLET	(6, "Raytrix_AOA_FF_Servlet"),
	TID_DETECTOR_SERVLET (7, "TID_Detector_Servlet"),
	TID_TRACKINFO_SERVLET (8, "TID_TrackInfo_Servlet"),
	TID_FINDTRACKS_SERVLET (9, "TID_FindTracks_Servlet");
	
	static private final Map<Integer,Application> mapById = new HashMap<>();
	static private final Map<String,Application> mapByName = new HashMap<>();
	static {
		for (Application application : values()) {
			if (mapById.put(application.getId(), application) != null) {
				throw new RuntimeException("Design error: duplicated Id, " + application.getId());
			}
			if (mapByName.put(application.getName().toLowerCase(), application) != null) {
				throw new RuntimeException("Design error: duplicated Id, " + application.getName());
			}
		}
	}
	
	private final int id;
	private final String name;
	
	private  Application(int id, String name) {
		this.id = id;
		this.name = name;
	}

	public int getId() {
		return id;
	}
	public String getName() {
		return name;
	}
	static public Application get(int id) {
		return mapById.get(id);
	}
	static public Application get(String name) {
		return mapByName.get(name.toLowerCase());
	}
}
