/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.database;

import edu.uml.lgdc.quantities.NO_VALUE;

public class ConnectList {
	static public final int NUMBER_OF_CONNECT_ITEMS = 20;

	private final ConnectItem[] connectItems;
	private int lastConnectIndex = NO_VALUE.INDEX;

	public ConnectList(ConnectItem[] connectItems, int lastConnectIndex) {
		assert connectItems != null && connectItems.length > 0;
		this.connectItems = connectItems;
		if (lastConnectIndex < 0 || lastConnectIndex >= connectItems.length) {
			lastConnectIndex = NO_VALUE.INDEX;
		}
		this.lastConnectIndex = lastConnectIndex;
	}

	public ConnectItem[] getConnectItems() {
		return connectItems;
	}
	public int getLastConnectIndex() {
		return lastConnectIndex;
	}
	public ConnectItem getLastConnectItem() {
		if (lastConnectIndex != NO_VALUE.INDEX) {
			return connectItems[lastConnectIndex];
		} else {
			return null;
		}
	}
	public void setLastConnectIndex(int lastConnectIndex) {
		this.lastConnectIndex = lastConnectIndex;
	}
	static public ConnectList parse(String connectListAsStr) {
		assert connectListAsStr != null;
		connectListAsStr = connectListAsStr.trim();
		assert connectListAsStr.length() > 0;
		String[] allItems = connectListAsStr.split(";");
		int connectIndex = Integer.parseInt(allItems[0]);
		ConnectItem[] connectItems = new ConnectItem[NUMBER_OF_CONNECT_ITEMS];
		for (int i = allItems.length - 1; i < NUMBER_OF_CONNECT_ITEMS; i++) {
			connectItems[i] = ConnectItem.createEmpty();
		}
		for (int i = 1, j = 0; i < allItems.length; i++, j++) {
			connectItems[j] = ConnectItem.parse(allItems[i]);
		}
		return new ConnectList(connectItems, connectIndex);
	}
	@Override public String toString() {
		// compress first
		ConnectItem[] tmpConnectItems = new ConnectItem[connectItems.length];
		System.arraycopy(connectItems, 0, tmpConnectItems, 0, connectItems.length);
		int compressedSize = 0;
		int lastConnectIndexInCompressedArray = lastConnectIndex;
		for (int i = 0; i < tmpConnectItems.length; i++) {
			if (lastConnectIndexInCompressedArray == i) {
				if (!tmpConnectItems[i].isEmpty()) {
					lastConnectIndexInCompressedArray = compressedSize;
				} else {
					lastConnectIndexInCompressedArray = NO_VALUE.INDEX;
				}
			}
			if (!tmpConnectItems[i].isEmpty()) {
				if (i > compressedSize) {
					tmpConnectItems[compressedSize] = tmpConnectItems[i];
				}
				compressedSize++;
			}
		}
		if (lastConnectIndexInCompressedArray >= compressedSize) {
			lastConnectIndexInCompressedArray = NO_VALUE.INDEX;
		}
		// and convert to string
		StringBuilder sb = new StringBuilder(1024).append(lastConnectIndexInCompressedArray);
		for (int i = 0; i < compressedSize; i++) {
			tmpConnectItems[i].append(sb.append(';'));
		}
		return sb.toString();
	}
	static public ConnectList createEmpty(int size) {
		ConnectItem[] connectItems = new ConnectItem[size];
		for (int i = 0; i < size; i++) {
			connectItems[i] = ConnectItem.createEmpty();
		}
		return new ConnectList(connectItems, NO_VALUE.INDEX);
	}
}
