/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.database;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;

import edu.uml.lgdc.time.TimeScale;

public class FirebirdUtil {
	static private final String SCHEME_SEP = "://";
	static private final String JDBC_FIREBIRD2_PROTOCOL_SEP = "jdbc:firebirdsql://";
	
	static public TimeScale getTime(ResultSet rs, int timestampIndex) throws SQLException {
		Timestamp timestamp = rs.getTimestamp(timestampIndex, TimeScale.TM);
		return getTime(rs, timestamp);
	}
	static public TimeScale getTime(ResultSet rs, String timestampColumnName) throws SQLException {
		Timestamp timestamp = rs.getTimestamp(timestampColumnName, TimeScale.TM);
		return getTime(rs, timestamp);
	}
	static private TimeScale getTime(ResultSet rs, Timestamp timestamp) throws SQLException {
		if (!rs.wasNull() && timestamp != null) {
			return new TimeScale(timestamp.getTime());
		} else {
			return null;
		}
	}
	
	/**
	 * This method is related with Firebird 2 family protocol which is starting part of database URL string.<br>
	 * First, it removes backslash symbol before two colons, if any,
	 * <ul>
	 *   <b>{@code jdbc\:firebirdsql\:}</b> &nbsp;&nbsp;&nbsp; => &nbsp;&nbsp;&nbsp; <b>{@code jdbc:firebirdsql:}</b> 
	 * </ul>
	 * And then checks that modified {@code url} starts with,
	 * <ul>
	 *   <b>{@code jdbc:firebirdsql:}</b> 
	 * </ul> 
	 * Returns possibly modified {@code url} if check id OK, otherwise returns <b>null</b><br>
	 * Note,
	 * <ul>
	 *   Firebird 2 family protocol is case sensitive, and has to be all in lowercase.
	 * </ul>
	 */
	static public String removeBackSlashesAndCheck(String url) {
		int pos = url.indexOf(SCHEME_SEP);
		if (pos <= 0) {
			return null;
		}
		String scheme_colon = url.substring(0, pos + 1);
		scheme_colon = scheme_colon.replace("\\:", ":");
		url = scheme_colon + url.substring(pos + 1);
		if (url.startsWith(JDBC_FIREBIRD2_PROTOCOL_SEP)) {
			return url;
		} else {
			return null;
		}
	}
}
