/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.database;

import java.util.HashMap;
import java.util.Map;

public enum SPColumnType {
	SPCT_UNKNOWN		(0, "nobody knows"), 
	SPCT_IN_PAR			(1, "IN parameter"), 
	SPCT_IN_OUT_PAR		(2, "INOUT parameter"), 
	SPCT_OUT_PAR		(3, "OUT parameter"),
	SPCT_RET_COL		(4, "procedure return value"), 
	SPCT_RE_COL_IN_RS	(5, "result column in ResultSet");
	
	static private final Map<Integer, SPColumnType> MAP_BY_ID = new HashMap<>();
	static {
		for (SPColumnType type : values())
			if (MAP_BY_ID.put(type.getId(), type) != null)
				throw new RuntimeException("Design error: duplicate id, " + type.getId());
	}
	private final int id;
	private final String desc;
	private SPColumnType(int id, String desc) {
		this.id = id;
		this.desc = desc;
	}
	public int getId() {
		return id;
	}
	public String getDesc() {
		return desc;
	}
	static public SPColumnType get(int id) {
		return MAP_BY_ID.get(id);
	}
}
