/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.database;

import java.util.List;

public class StoredProcedure {
	private final String name;
	private final List<SPColumn> columns;
	public StoredProcedure(String name, List<SPColumn> columns) {
		this.name = name.toUpperCase();
		this.columns = columns;
	}
	public String getName() {
		return name;
	}
	public List<SPColumn> getColumns() {
		return columns;
	}
	public boolean isColumn(SPColumn column) {
		return getColumn(column) != null;
	}
	public SPColumn getColumn(SPColumn column) {
		int index = columns.indexOf(column);
		if (index >= 0)
			return columns.get(index);
		else
			return null;
	}
	public boolean addColumn(SPColumn column) {
		if (columns.indexOf(column) < 0) {
			columns.add(column);
			return true;
		} else {
			return false;
		}
	}
	@Override public boolean equals(Object object) {
		if (object != null && object instanceof StoredProcedure) {
			StoredProcedure sp = (StoredProcedure)object;
			return name.equals(sp.name) && columns.equals(sp.columns);
		} else {
			return false;
		}
	}
	@Override public int hashCode() {
		return name.hashCode() + 31 * columns.hashCode();
	}
}
