package edu.uml.lgdc.geospace;

import static edu.uml.lgdc.geospace.MapTypeChoice.CLIMATE;
import static edu.uml.lgdc.geospace.MapTypeChoice.DELTA;
import static edu.uml.lgdc.geospace.MapTypeChoice.DELTA_PERCENT;
import static edu.uml.lgdc.geospace.MapTypeChoice.WEATHER;

import edu.uml.lgdc.geospace.MapChoice;


/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/

public enum MapChoice {
	FOF2_CLIMATE("foF2: URSI-88 climate", "Classic foF2 climate by IRI URSI-88", CLIMATE, false, 0, CharChoice.FOF2.getDidbaseIdent()), 
	FOF2_WEATHER("foF2: IRTAM outcome", "IRTAM Global Weather map of foF2", WEATHER, false, 0, CharChoice.FOF2.getDidbaseIdent()), 
	FOF2_DELTA("foF2: IRTAM versus IRI URSI-88", "Deviation of IRTAM from IRI foF2", DELTA, false, 0, CharChoice.FOF2.getDidbaseIdent()), 
	FOF2_DELTA_PERCENT("foF2: IRTAM versus URSI-88","Percent deviation of IRTAM from IRI foF2", DELTA_PERCENT, false, 0,CharChoice.FOF2.getDidbaseIdent()), 
	NMF2_CLIMATE("NmF2: URSI-88 climate", "Classic NmF2 climate by IRI URSI-88", CLIMATE, false, 0, CharChoice.NMF2.getDidbaseIdent()), 
	NMF2_WEATHER("NmF2: IRTAM outcome", "IRTAM Global Weather map of NmF2", WEATHER, false, 0, CharChoice.NMF2.getDidbaseIdent()), 
	NMF2_DELTA("NmF2: IRTAM versus IRI URSI-88", "Deviation of IRTAM from IRI NmF2", DELTA, false, 0, CharChoice.NMF2.getDidbaseIdent()), 
	NMF2_DELTA_PERCENT("NmF2: IRTAM versus URSI-88","Percent deviation of IRTAM from IRI NmF2", DELTA_PERCENT, false, 0,CharChoice.NMF2.getDidbaseIdent()), 
	HMF2_CLIMATE("hmF2: climate", "hmF2 climate based on [Brunini et al., 2013] coefficients", CLIMATE, false, 0, CharChoice.HMF2.getDidbaseIdent()), 
	HMF2_WEATHER("hmF2: IRTAM outcome", "IRTAM Global Weather map of hmF2", WEATHER, false, 0, CharChoice.HMF2.getDidbaseIdent()), 
	HMF2_DELTA("hmF2: IRTAM versus Brunini", "Deviation of IRTAM from [Brunini et al., 2013] hmF2", DELTA, false, 0, CharChoice.HMF2.getDidbaseIdent()), 
	HMF2_DELTA_PERCENT("hmF2: IRTAM versus Brunini","Percent deviation of IRTAM from [Brunini et al., 2013] hmF2", DELTA_PERCENT, false, 0, CharChoice.HMF2.getDidbaseIdent()), 
	B0_CLIMATE("B0: climate", "B0 climate based on IRI-2016", CLIMATE, false, 0, CharChoice.B0.getDidbaseIdent()), 
	B0_WEATHER("B0: IRTAM outcome", "IRTAM Global Weather map of B0", WEATHER, false, 0, CharChoice.B0.getDidbaseIdent()), 
	B0_DELTA("B0: IRTAM versus IRI-2016", "Deviation of IRTAM from IRI-2016 B0", DELTA, false, 0, CharChoice.B0.getDidbaseIdent()), 
	B0_DELTA_PERCENT("B0: IRTAM versus IRI-2016","Percent deviation of IRTAM from IRI-2016 B0", DELTA_PERCENT, false, 0, CharChoice.B0.getDidbaseIdent()), 
	B1_CLIMATE("B1: climate", "B1 climate based on IRI-2016", CLIMATE, false, 0, CharChoice.B1.getDidbaseIdent()), 
	B1_WEATHER("B1: IRTAM outcome", "IRTAM Global Weather map of B1", WEATHER, false, 0, CharChoice.B1.getDidbaseIdent()), 
	B1_DELTA("B1: IRTAM versus IRI-2016", "Deviation of IRTAM from IRI-2016 B1", DELTA, false, 0, CharChoice.B1.getDidbaseIdent()), 
	B1_DELTA_PERCENT("B1: IRTAM versus IRI-2016","Percent deviation of IRTAM from IRI-2016 B1", DELTA_PERCENT, false, 0, CharChoice.B1.getDidbaseIdent()), 
	GK("foF2: Geofunction Gk", "Jones-Gallet geographic function Gk, k=1..76", MapTypeChoice.GK, true, 12, CharChoice.FOF2.getDidbaseIdent()); 

	private final String shortName;
	private final String description;
	private final MapTypeChoice type;
	private final boolean configurable;
	private int parameter;
	private int charIdent;

	static {
		boolean isMapTypeDefined[] = new boolean[MapChoice.values().length];
		int iChoice = 0;
		for (MapChoice choice : MapChoice.values()) {
			isMapTypeDefined[iChoice] = false;
			isMapTypeDefined[iChoice] = isDeltaMap(choice) || isPercentDeltaMap(choice) || isCharMap(choice) || isDebugMap(choice);
			iChoice++;
		}
		iChoice = 0;
		for (MapChoice choice : MapChoice.values()) {
			if (!isMapTypeDefined[iChoice])
				throw new RuntimeException("Type is not defined for " + choice.toString() + " in MapChoice.");
			iChoice++;
		}
	}

	static {
		for (CharChoice cc : CharChoice.values()) {
			for (MapTypeChoice stc : MapTypeChoice.values()) {
				if (getSurfaceChoice(cc, stc) == null) {
					throw new RuntimeException("Define MapChoice for CharChoice " + cc.name() + " and MapTypeChoice " + stc.name());
				}
			}
		}
	}

	private MapChoice(String shortName, String description, MapTypeChoice type, boolean configurable, int parameter, int charIdent) {
		this.shortName = shortName;
		this.description = description;
		this.type = type;
		this.configurable = configurable;
		this.parameter = parameter;
		this.charIdent = charIdent;
	}

	static public MapChoice getSurfaceChoice(CharChoice cc, MapTypeChoice stc) {
		try {
			String fullName = (stc == MapTypeChoice.GK? "" : cc.name()+"_") + stc.name();
			return MapChoice.valueOf( fullName );
		} catch (Exception e) {
			return null;
		}
	}

	public String shortName() {
		return shortName;
	}

	public String getDescription() {
		return description;
	}

	public MapTypeChoice getType() {
		return type;
	}

	public String getToolTip() {
		return "<html>" + description.replace("\n", "<br>") + "<html>";
	}

	public boolean configurable() {
		return configurable;
	}

	public int parameter() {
		return parameter;
	}

	public CharChoice getCC() {
		return CharChoice.getByIdent(charIdent);
	}

	public void setParameter(int p) {
		parameter = p;
	}

	static private boolean isClimateMap(MapChoice choice) {
		return (choice == FOF2_CLIMATE || choice == NMF2_CLIMATE || choice == HMF2_CLIMATE || choice == B0_CLIMATE 
				|| choice == B1_CLIMATE);
	}

	public boolean isClimateMap() {
		return isClimateMap(this);
	}

	static private boolean isWeatherMap(MapChoice choice) {
		return (choice == FOF2_WEATHER || choice == NMF2_WEATHER || choice == HMF2_WEATHER || choice == B0_WEATHER 
				|| choice == B1_WEATHER);
	}

	public boolean isWeatherMap() {
		return isWeatherMap(this);
	}

	static private boolean isDeltaMap(MapChoice choice) {
		return (choice == FOF2_DELTA || choice == FOF2_DELTA_PERCENT || choice == NMF2_DELTA || choice == NMF2_DELTA_PERCENT
				|| choice == HMF2_DELTA || choice == HMF2_DELTA_PERCENT 
				|| choice == B0_DELTA || choice == B0_DELTA_PERCENT || choice == B1_DELTA || choice == B1_DELTA_PERCENT);
	}

	public boolean isDeltaMap() {
		return isDeltaMap(this);
	}

	static private boolean isPercentDeltaMap(MapChoice choice) {
		return (choice == FOF2_DELTA_PERCENT || choice == NMF2_DELTA_PERCENT 
				|| choice == HMF2_DELTA_PERCENT || choice == B0_DELTA_PERCENT 
				|| choice == B1_DELTA_PERCENT ); 
	}

	public boolean isPercentDeltaMap() {
		return isPercentDeltaMap(this);
	}

	static private boolean isCharMap(MapChoice choice) {
		return (choice == FOF2_CLIMATE || choice == FOF2_WEATHER || choice == NMF2_CLIMATE 
				|| choice == NMF2_WEATHER || choice == HMF2_CLIMATE || choice == HMF2_WEATHER 
				|| choice == B0_CLIMATE	|| choice == B0_WEATHER || choice == B1_CLIMATE 
				|| choice == B1_WEATHER ); 
	}

	public boolean isCharMap() {
		return isCharMap(this);
	}


	static private boolean isDebugMap(MapChoice choice) {
		return (choice == GK ); 
	}
	
	public boolean isDebugMap() {
		return isDebugMap(this);
	}

	static public int length() {
		return values().length;
	}

	static public MapChoice get(int ordinal) {
		if (check(ordinal))
			return values()[ordinal];
		else
			throw new IllegalArgumentException("Illegal SurfaceChoice ordinal, " + ordinal);
	}

	static public String[] shortNames(boolean initialCaps) {
		final MapChoice[] values = values();
		String[] shortNames = new String[values.length];
		for (int i = 0; i < values.length; i++)
			shortNames[i] = values[i].shortName;
		return shortNames;
	}

	static public boolean check(int value) {
		return value >= 0 && value < values().length;
	}

}
