/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.geospace;

public enum MapTypeChoice {
	CLIMATE("Climate", "Classic climatology model", false), 
	WEATHER("IRTAM Weather", "IRI-based Real-time assimilative map (IRTAM) weather", false), 
	DELTA("IRTAM versus Climate", "Difference between IRTAM and Climate model", false), 
	DELTA_PERCENT("IRTAM versus Climate", "Percent difference between IRTAM and Climate model", false), 
	GK("Geofunctions Gk", "Jones-Gallet geographic function Gk, k=1..76", false); 

	private final String shortName;
	private final String description;
	private final String description_tooltip;
	private final boolean access;

	private MapTypeChoice(String name, String description, boolean access) {
		this.shortName = name;
		this.description = description;
		this.description_tooltip = "<html>" + description.replaceAll("\n", "<br>") + "</html>";
		this.access = access;
	}

	public boolean isAccess() {
		return access;
	}

	public String getShortName() {
		return shortName;
	}

	public String getDescription() {
		return description;
	}

	public String getDescription_tooltip() {
		return description_tooltip;
	}
}
