/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.geospace;

public class PlasmaMath {
	/** [MHz] to [cm^-3] */
	private static final double coef2Ne = 1.E6 / 80.6;
	/** [MHz] to [m^-3] */
	private static final double coef2Ne_m3 = coef2Ne * 1.E6;
	/** [TEC units] to [m^-2] */
	private static final double coef2tec = 1.E16;
	/** [TEC units] to [cm^-2] */
	private static final double coef2tec_cm2 = coef2tec / 1.E4;

	/** Slab thickness in km */
	private static final double coefTau = coef2tec_cm2 * 1.E-5;

	/** standard methods use cm-3 */
	public static double freq2density(double freq_MHz) {
		return coef2Ne * freq_MHz * freq_MHz;
	}

	public static double density2freq(double density_cm3) {
		return Math.sqrt(density_cm3 / coef2Ne);
	}

	/** optional methods use m-3 */
	public static double freq2density_m3(double freq_MHz) {
		return freq_MHz * freq_MHz * coef2Ne_m3;
	}

	public static double density2freq_m3(double density_m3) {
		return Math.sqrt(density_m3 / coef2Ne_m3);
	}

	public static double tecu2tec_m2(double tec_units) {
		return tec_units * coef2tec;
	}

	public static double tecu2tec_cm2(double tec_units) {
		return tec_units * coef2tec_cm2;
	}

	public static double slabThickness_km(double tec_units, double NmF2_cm3) {
		return coefTau * tec_units / NmF2_cm3;
	}

}
