/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.math;

import edu.uml.lgdc.quantities.NO_VALUE;

/**
 * 
 * Simple statistical metrics for input data array with gaps (indicated by NO_VALUE) 
 *  * @author Galkin
 *
 */
public class SimpleMetrics {
	public double min;
	public double max;
	public double average;
	public double standardDeviation;

	public void compute( double[] input, int length, double noValue ) {
	
		min = Double.MAX_VALUE;
		max = -Double.MAX_VALUE;
		int count = 0;
		standardDeviation = 0;
		average = 0;
		for (int i = 0; i < length; i++) {
			if (input[i] != noValue) {
				count++;
				average += input[i];
				min = Math.min(min, input[i]);
				max = Math.max(max, input[i]);
			}
		}
		if (count > 0) {
			average /= count;
			count = 0;
			for (int i = 0; i < input.length; i++) {
				if (input[i] != noValue) {
					standardDeviation += (average - input[i]) * (average - input[i]);
					count++;
				}
			}
			standardDeviation = standardDeviation / count;
			standardDeviation = Math.sqrt(standardDeviation);
		}
	}

	public void clear() {
		min = max = average = standardDeviation = NO_VALUE.SPECIAL;
	}	
}
