package edu.uml.lgdc.project;

import java.io.File;

/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
public class CommonConst {
	// -------------------------------------------------------------
	// Project name, Application name, version, copyright, full name
	// -------------------------------------------------------------
	static private String projectName;
	static private String applicationName;
	static private String applicationShortName;
	static private String applicationVersion;
	static private String applicationCopyright;
	static private String applicationFullName;
	/**
	 * Working directory location
	 */
	static private String workingDir = System.getProperty("user.dir");
	/**
	 * User/Home directory location
	 */
	static private String userDir = workingDir;
	/**
	 * Shared resources directory location
	 */
	static private String shareResourcesDir = workingDir;
	/**
	 * Temporary directory location
	 */
	static private String tempDir = System.getProperty("java.io.tmpdir");
	/**
	 * <b>true</b>, if application has write access to Shared directory
	 */
	static private boolean writeAccessToShareDir;

	static private String fileTimeFormat;
	static private String dateFormatOneDayPattern;
	static private String dateFormatIndividualPattern;
	static private String dateFormatLookPattern;

	static private final Object syncTempDirCreation = new Object();
	transient static private volatile boolean tempDirWasChecked;

	// -----------------------------------
	// ControlPar reference
	// -----------------------------------

	static private ControlPar cp;

	static public String getProjectName() {
		return projectName;
	}
	static public void setProjectName(String value) {
		projectName = value;
	}
	static public String getApplicationName() {
		return applicationName;
	}
	static public void setApplicationName(String value) {
		applicationName = value;
	}
	static public String getApplicationShortName() {
		return applicationShortName;
	}
	static public void setApplicationShortName(String value) {
		applicationShortName = value;
	}
	static public String getApplicationVersion() {
		return applicationVersion;
	}
	static public void setApplicationVersion(String value) {
		applicationVersion = value;
	}
	static public String getApplicationCopyright() {
		return applicationCopyright;
	}
	static public void setApplicationCopyright(String value) {
		applicationCopyright = value;
	}
	static public String getApplicationFullName() {
		return applicationFullName;
	}
	static public void setApplicationFullName(String value) {
		applicationFullName = value;
	}
	static public String getWorkingDir() {
		return workingDir;
	}
	// method setWorkingDir is absent as it is not applicable - Working Directory can not be changed in Java
	static public String getUserDir() {
		return userDir;
	}
	static public void setUserDir(String value) {
		userDir = value;
	}
	static public String getShareResourcesDir() {
		return shareResourcesDir;
	}
	static public void setShareResourcesDir(String value) {
		System.out.println("CommonConst: resource folder set to "+value);
		shareResourcesDir = value;
	}
	static public boolean getWriteAccessToShareDirEnabled() {
		return writeAccessToShareDir;
	}
	static public void setWriteAccessToShareDirEnabled(boolean value) {
		writeAccessToShareDir = value;
	}
	static public String getTempDir() {
		if (!tempDirWasChecked) {
			synchronized (syncTempDirCreation) {
				if (!tempDirWasChecked) {
					File dir = new File(tempDir);
					if (!dir.isDirectory()) {
						if (!dir.mkdir())
							Console.showError("Can not create temporary directory: " + tempDir);
					}
					tempDirWasChecked = true;
				}
			}
		}
		return tempDir;
	}
	static public void setTempDir(String value) {
		tempDir = value;
	}
	static public String getFileTimeFormat() {
		return fileTimeFormat;
	}
	static public void setFileTimeFormat(String format) {
		fileTimeFormat = format;
	}
	static public String getDateFormatOneDayPattern() {
		return dateFormatOneDayPattern;
	}
	static public void setDateFormatOneDayPattern(String value) {
		dateFormatOneDayPattern = value;
	}
	static public String getDateFormatIndividualPattern() {
		return dateFormatIndividualPattern;
	}
	static public void setDateFormatIndividualPattern(String value) {
		dateFormatIndividualPattern = value;
	}
	static public String getDateFormatLookPattern() {
		return dateFormatLookPattern;
	}
	static public void setDateFormatLookPattern(String value) {
		dateFormatLookPattern = value;
	}
	static public ControlPar getCP() {
		return cp;
	}
	static public void setCP(ControlPar value) {
		cp = value;
	}
}