package edu.uml.lgdc.project;

import java.awt.Frame;
import java.awt.Toolkit;
import java.io.File;
import java.io.PrintWriter;

import javax.swing.JTextArea;

import edu.uml.lgdc.database.ConnectContainer;
import edu.uml.lgdc.database.DBConnect;
import edu.uml.lgdc.instrument.AbstractStation;

/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
public class ControlPar<S extends AbstractStation> implements ProductInfo, ConnectContainer {
	// for locking operation on taLogOutput
	public final Object taLogOutputLock = new Object();
	private String appName = "Untitled";
	private String appShortName = "Untitled";
	private String appVersion = "2.0";
	private String copyright = "Copyright (c) 2001-2012";
	private String appFullName = "Untitled";

	public String driverName = "org.firebirdsql.jdbc.FBDriver";
	public String databaseURL = "jdbc:firebirdsql://localhost/<db filename>";
	public String user = "SYSDBA";
	public String password;

	protected DBConnect connect;

	public String dataInputPath;

	private boolean consoleMode;
	private boolean batchMode;

	public PrintWriter logOutput;
	public JTextArea taLogOutput;
	public Frame mainFrame;

	public boolean isConsoleMode() {
		return consoleMode;
	}
	public void setConsoleMode(boolean value) {
		consoleMode = value;
	}
	public boolean isBatchMode() {
		return batchMode;
	}
	public void setBatchMode(boolean value) {
		batchMode = value;
	}
	@Override public DBConnect getDbConnect() {
		return connect;
	}
	@Override public void setDbConnect(DBConnect connect) {
		this.connect = connect;
	}
	public boolean isConnected() {
		return connect != null && connect.isConnected();
	}
	
	/**
	 * Check for given directory <code>dirName</code> exists. If exists, returns absolute path of this directory.
	 * If not exists, tries to create it and if,
	 * <ul>
	 *   <li>success, then returns absolute path of this directory</li>
	 *   <li>failure, then returns <b>null</b></li> 
	 * </ul>
	 */
	public static String checkLocalDir(String dirName) {
		if (dirName == null)
			throw new IllegalArgumentException("dirName is null");
		if (dirName.length() == 0)
			throw new IllegalArgumentException("dirName.length() == 0");
		File file = new File(dirName);
		if (file.isDirectory())
			return file.getAbsolutePath();
		synchronized (ControlPar.class) {
			if (file.isDirectory())
				return file.getAbsolutePath();
			if (file.exists()) {
				Console.showError("checkLocalDir(): name " + dirName + " is already ocuppied by file or volume object");
				return null;
			}
			if (file.mkdir())
				return file.getAbsolutePath();
			Console.showError("checkLocalDir(): can not create directory " + dirName);
			return null;
		}
	}
	public String getAppName() {
		return appName;
	}
	public void setAppName(String appName) {
		this.appName = appName;
	}
	public String getAppShortName() {
		return appShortName;
	}
	public void setAppShortName(String appShortName) {
		this.appShortName = appShortName;
	}
	public String getAppVersion() {
		return appVersion;
	}
	public void setAppVersion(String appVersion) {
		this.appVersion = appVersion;
	}
	public String getCopyright() {
		return copyright;
	}
	public void setCopyright(String copyright) {
		this.copyright = copyright;
	}
	public String getAppFullName() {
		return appFullName;
	}
	public void setAppFullName(String appFullName) {
		this.appFullName = appFullName;
	}
}