/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.project;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

public class SharedResourcesDir {
	static public final String NOT_SET = new String();
	
	private SharedResourcesDir() {
	}
	
	static public String readAndSet(CommandLineParam commandLineParam) {
		return readAndSet(commandLineParam, new HashSet<>(Arrays.asList("sd")));
	}
	static public String readAndSet(CommandLineParam commandLineParam, Set<String> synonyms) {
		String errMsg = null;
		String sharedDir = null;
		if (commandLineParam.isKeyExists(synonyms)) {
			sharedDir = commandLineParam.getKeyValue(synonyms);
			if (sharedDir != null) {
				if (new File(sharedDir).isDirectory()) {
					try {
						sharedDir = new File(sharedDir).getCanonicalPath();
					} catch (IOException ex) {
						errMsg = ex.toString();
					}
				} else {
					errMsg = "Illegal directory " + sharedDir + " does not exist";
				}
			}
		}
		if (errMsg != null) {
			return errMsg;
		} else if (sharedDir != null) {
			CommonConst.setShareResourcesDir(sharedDir);
			return null;
		} else {
			return NOT_SET;
		}
	}
}
