/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.project.settings;

public class FromStrHelper {
	public static class Result {
		public final String errMsg;
		public final Object value;
		public final boolean isDefaultValue;
		
		Result(String errMsg, Object value) {
			this(errMsg, value, false);
		}
		Result(String errMsg, Object value, boolean isDefaultValue) {
			if (errMsg != null && value != null) {
				throw new IllegalArgumentException("value has to be null when errMsg is not null");
			}
			this.errMsg = errMsg;
			this.value = value;
			this.isDefaultValue = isDefaultValue;
		}
	}

	static public Result getInt(String strValue) {
		if (strValue != null) {
			strValue = strValue.trim();
			if (!strValue.isEmpty()) {
				try {
					return new Result(null, Integer.parseInt(strValue));
				} catch (NumberFormatException ex) {
					return new Result(ex.getMessage(), null);
				}
			}
		}
		return new Result(null, null, true);
	}

	static public Result getPositiveInt(String strValue) {
		Result result = getInt(strValue);
		if (result.errMsg == null) {
			if (!result.isDefaultValue) {
				int intVal = (Integer)result.value; 
				if (intVal >= 0) {
					return result;
				} else {
					return new Result("value is < 0, " + intVal, null);
				}
			}
		}
		return result;
	}

	static public Result getStrictPositiveInt(String strValue) {
		Result result = getInt(strValue);
		if (result.errMsg == null) {
			if (!result.isDefaultValue) {
				int intVal = (Integer)result.value; 
				if (intVal > 0) {
					return result;
				} else {
					return new Result("value is <= 0, " + intVal, null);
				}
			}
		}
		return result;
	}

	static public Result getBoolean(String strValue, boolean defaultValue) {
		if (strValue != null) {
			strValue = strValue.trim();
			if (!strValue.isEmpty()) {
				if (strValue.equalsIgnoreCase("true") || strValue.equalsIgnoreCase("yes")) {
					return new Result(null, true);
				} else if (strValue.equalsIgnoreCase("false") || strValue.equalsIgnoreCase("no")) {
					return new Result(null, false);
				} else {
					return new Result("illegal boolean value, " + strValue, null);
				}
			}
		}
		return new Result(null, defaultValue, true);
	}
}
