/*******************************************************************************
 * Copyright (c) 2004, 2018 University of Massachusetts Lowell
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Creative Commons 
 * Attribution-ShareAlike 2.0 (CC BY-SA 2.0) available at
 * https://creativecommons.org/licenses/by-sa/2.0/ with the 
 * attribution clause "Lowell GIRO Data Center Rules of the Road"
 * available at http://umlcar.uml.edu/DIDBase/RulesOfTheRoadForDIDBase.htm
 *******************************************************************************/
package edu.uml.lgdc.time;

import java.util.HashMap;
import java.util.Map;

public enum TimeType {
	UT		("Universal Time", false),
	LMT		("Local Mean Time", true),
	AZT		("Abstract Zone Time", true);
	static final private int MIN_LOCAL_TIME_ORDINAL = LMT.ordinal();
	static final private Map<String,TimeType> MAP_BY_NAME = new HashMap<String,TimeType>();
	static {
		for (TimeType timeType : values()) {
			if (MAP_BY_NAME.put(timeType.getName(), timeType) != null)
				throw new RuntimeException("design error: value " + timeType + " duplicated");
		}
	}
	private final String name;
	private final boolean local;
	private TimeType(String name, boolean local) {
		this.name = name;
		this.local = local;
	}
	public String getName() {return name;}
	public boolean isLocal() {return local;}
	public int getLocalOrdinal() {
		if (local)
			return ordinal() - MIN_LOCAL_TIME_ORDINAL;
		else
			throw new RuntimeException("illegal call");
	}
	static public TimeType getLocalTimeByItsOrdinal(int localTimeOrdinal) {
		if (localTimeOrdinal >= 0 && localTimeOrdinal < values().length - MIN_LOCAL_TIME_ORDINAL)
			return values()[MIN_LOCAL_TIME_ORDINAL + localTimeOrdinal];
		else
			return null;
	}
	static public String[] getLocalTimeTypeNames() {
		String[] names = new String[values().length - MIN_LOCAL_TIME_ORDINAL];
		for (int i = 0; i < names.length; i++)
			names[i] = getLocalTimeByItsOrdinal(i).getName();
		return names;
	}
	static public TimeType getByName(String name) {
		return MAP_BY_NAME.get(name);
	}
}